@@ -255,6 +255,7 @@ void MainWindow::createTrayIcon()
     m_pTrayIconMenu->addAction(ui_->m_pActionStartCmdApp);
     m_pTrayIconMenu->addAction(ui_->m_pActionStopCmdApp);
     m_pTrayIconMenu->addAction(ui_->m_pActionShowLog);
+    m_pTrayIconMenu->addAction(ui_->m_pActionReload);
     m_pTrayIconMenu->addSeparator();
 
     m_pTrayIconMenu->addAction(ui_->m_pActionMinimize);
@@ -341,6 +342,7 @@ void MainWindow::initConnections()
     connect(ui_->m_pActionStartCmdApp, &QAction::triggered, this, &MainWindow::start_cmd_app);
     connect(ui_->m_pActionStopCmdApp, &QAction::triggered, this, &MainWindow::stop_cmd_app);
     connect(ui_->m_pActionShowLog, &QAction::triggered, this, &MainWindow::showLogWindow);
+    connect(ui_->m_pActionReload, &QAction::triggered, this, &MainWindow::restart_cmd_app);
     connect(ui_->m_pActionQuit, &QAction::triggered, qApp, &QCoreApplication::quit);
 }
 
@@ -390,7 +392,11 @@ void MainWindow::logOutput()
     if (cmd_app_process_)
     {
         QString text(cmd_app_process_->readAllStandardOutput());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const auto results = text.split(QRegularExpression("\r|\n|\r\n"));
+#else
+        const auto results = text.split(QRegExp("\r|\n|\r\n"));
+#endif
         for (const auto& line : results) {
             if (!line.isEmpty())
             {
@@ -428,7 +434,12 @@ void MainWindow::appendLogError(const QString& text)
 
 void MainWindow::appendLogRaw(const QString& text)
 {
-    for (const auto& line : text.split(QRegularExpression("\r|\n|\r\n"))) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    const auto lines = text.split(QRegularExpression("\r|\n|\r\n"));
+#else
+    const auto lines = text.split(QRegExp("\r|\n|\r\n"));
+#endif
+    for (const auto& line : lines) {
         if (!line.isEmpty()) {
             m_pLogWindow->appendRaw(line);
             updateFromLogLine(line);
@@ -467,6 +478,7 @@ void MainWindow::checkConnected(const QString& line)
 
 void MainWindow::checkFingerprint(const QString& line)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QRegularExpression fingerprintRegex("peer fingerprint \\(SHA1\\): ([A-F0-9:]+) \\(SHA256\\): ([A-F0-9:]+)$");
     QRegularExpressionMatch match = fingerprintRegex.match(line);
     if (!match.hasMatch()) {
@@ -475,6 +487,15 @@ void MainWindow::checkFingerprint(const QString& line)
 
     auto match1 = match.captured(1).toStdString();
     auto match2 = match.captured(2).toStdString();
+#else
+    QRegExp fingerprintRegex(".*peer fingerprint \\(SHA1\\): ([A-F0-9:]+) \\(SHA256\\): ([A-F0-9:]+)");
+    if (!fingerprintRegex.exactMatch(line)) {
+        return;
+    }
+
+    auto match1 = fingerprintRegex.cap(1).toStdString();
+    auto match2 = fingerprintRegex.cap(2).toStdString();
+#endif
 
     inputleap::FingerprintData fingerprint_sha1 = {
         inputleap::fingerprint_type_to_string(inputleap::FingerprintType::SHA1),
@@ -1226,7 +1247,11 @@ bool MainWindow::isServiceRunning(QString name)
 
     auto array = name.toLocal8Bit();
 
+#if QT_VERSION_MAJOR < 6
+    SC_HANDLE hService = OpenService(hSCManager, array.data(), SERVICE_QUERY_STATUS);
+#else
     SC_HANDLE hService = OpenService(hSCManager, reinterpret_cast<LPCWSTR>(array.data()), SERVICE_QUERY_STATUS);
+#endif
     if (hService == nullptr) {
         appendLogDebug("failed to open service: " + name);
         return false;
@@ -1293,7 +1318,11 @@ void MainWindow::downloadBonjour()
         m_DownloadMessageBox->setWindowTitle("InputLeap");
         m_DownloadMessageBox->setIcon(QMessageBox::Information);
         m_DownloadMessageBox->setText("Installing Bonjour, please wait...");
-        m_DownloadMessageBox->setStandardButtons(QMessageBox::NoButton);        
+#if QT_VERSION_MAJOR < 6
+        m_DownloadMessageBox->setStandardButtons(0);
+#else
+        m_DownloadMessageBox->setStandardButtons(QMessageBox::NoButton);
+#endif
         m_pCancelButton = m_DownloadMessageBox->addButton(
             tr("Cancel"), QMessageBox::RejectRole);
     }
@@ -1308,7 +1337,12 @@ void MainWindow::downloadBonjour()
 void MainWindow::installBonjour()
 {
 #if defined(Q_OS_WIN)
+#if QT_VERSION >= 0x050000
     QString tempLocation = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
+#else
+    QString tempLocation = QDesktopServices::storageLocation(
+                                QDesktopServices::TempLocation);
+#endif
     QString filename = tempLocation;
     filename.append("\\").append(bonjourTargetFilename);
     QFile file(filename);
