@@ -1186,10 +1186,6 @@ MSWindowsKeyState::getKeyMap(inputleap::KeyMap& keyMap)
 
 					case VK_SNAPSHOT:
 						item.m_sensitive |= KeyModifierAlt;
-						if ((i & 0x100u) == 0) {
-							// non-extended snapshot key requires alt
-							item.m_required |= KeyModifierAlt;
-						}
 						break;
 					}
 					addKeyEntry(keyMap, item);
@@ -1349,8 +1345,20 @@ MSWindowsKeyState::getIDForKey(inputleap::KeyMap::KeyItem& item,
 	KeyID id = static_cast<KeyID>(unicode[0]);
 
 	switch (n) {
-	case -1:
-		return inputleap::KeyMap::getDeadKey(id);
+	case -1: {
+        // dead key. add an space to the keyboard so we exit
+        // the dead key mode and future calls to this function
+        // with different modifiers are not affected.
+
+        BYTE emptyState[256] = { };
+        n = m_ToUnicodeEx(VK_SPACE, 0, emptyState, unicode,
+                          sizeof(unicode) / sizeof(unicode[0]), 0, hkl);
+
+        // as an alternative, we could use the returned
+        // buffer in unicode to look at the dead key character
+        // and not rely on getDeadKey to provide the mapping
+        return inputleap::KeyMap::getDeadKey(id);
+    }
 
 	default:
 	case 0:
