@@ -18,6 +18,7 @@
 
 #include "platform/XWindowsScreen.h"
 
+#include "platform/XKBUtil.h"
 #include "platform/XWindowsClipboard.h"
 #include "platform/XWindowsEventQueueBuffer.h"
 #include "platform/XWindowsKeyState.h"
@@ -371,7 +372,7 @@ XWindowsScreen::setClipboard(ClipboardID id, const IClipboard* clipboard)
 		if (!m_clipboard[id]->open(timestamp)) {
 			return false;
 		}
-		m_clipboard[id]->empty();
+        m_clipboard[id]->clear();
 		m_clipboard[id]->close();
 		return true;
 	}
@@ -664,9 +665,7 @@ std::uint32_t XWindowsScreen::registerHotKey(KeyID key, KeyModifierMask mask)
 				toggleModifiers[numToggleModifiers++] = modifier;
 			}
 
-
-			for (XWindowsKeyState::KeycodeList::iterator j = keycodes.begin();
-									j != keycodes.end() && !err; ++j) {
+            for (auto j = keycodes.begin(); j != keycodes.end() && !err; ++j) {
 				for (size_t i = 0; i < (1u << numToggleModifiers); ++i) {
 					// add toggle modifiers for index i
 					unsigned int tmpModifiers = modifiers;
@@ -694,8 +693,7 @@ std::uint32_t XWindowsScreen::registerHotKey(KeyID key, KeyModifierMask mask)
 
 	if (err) {
 		// if any failed then unregister any we did get
-		for (HotKeyList::iterator j = hotKeys.begin();
-								j != hotKeys.end(); ++j) {
+        for (auto j = hotKeys.begin(); j != hotKeys.end(); ++j) {
             m_impl->XUngrabKey(m_display, j->first, j->second, m_root);
 			m_hotKeyToIDMap.erase(HotKeyItem(j->first, j->second));
 		}
@@ -713,7 +711,7 @@ std::uint32_t XWindowsScreen::registerHotKey(KeyID key, KeyModifierMask mask)
 void XWindowsScreen::unregisterHotKey(std::uint32_t id)
 {
 	// look up hotkey
-	HotKeyMap::iterator i = m_hotKeys.find(id);
+    auto i = m_hotKeys.find(id);
 	if (i == m_hotKeys.end()) {
 		return;
 	}
@@ -723,8 +721,7 @@ void XWindowsScreen::unregisterHotKey(std::uint32_t id)
 	{
 		XWindowsUtil::ErrorLock lock(m_display, &err);
 		HotKeyList& hotKeys = i->second;
-		for (HotKeyList::iterator j = hotKeys.begin();
-								j != hotKeys.end(); ++j) {
+        for (auto j = hotKeys.begin(); j != hotKeys.end(); ++j) {
             m_impl->XUngrabKey(m_display, j->first, j->second, m_root);
 			m_hotKeyToIDMap.erase(HotKeyItem(j->first, j->second));
 		}
@@ -1462,8 +1459,7 @@ bool
 XWindowsScreen::onHotKey(XKeyEvent& xkey, bool isRepeat)
 {
 	// find the hot key id
-	HotKeyToIDMap::const_iterator i =
-		m_hotKeyToIDMap.find(HotKeyItem(xkey.keycode, xkey.state & SCROLL_LOCK_EXCLUDE_MASK));
+    auto i = m_hotKeyToIDMap.find(HotKeyItem(xkey.keycode, xkey.state & SCROLL_LOCK_EXCLUDE_MASK));
 	if (i == m_hotKeyToIDMap.end()) {
 		return false;
 	}
@@ -1827,7 +1823,7 @@ XWindowsScreen::mapKeyFromX(XKeyEvent* event) const
 	LOG_DEBUG2("mapped code=%d to keysym=0x%04lx", event->keycode, keysym);
 
 	// convert key
-	KeyID result = XWindowsUtil::mapKeySymToKeyID(keysym);
+	KeyID result = XKBUtil::mapKeySymToKeyID(keysym);
 	LOG_DEBUG2("mapped keysym=0x%04lx to keyID=%d", keysym, result);
 	return result;
 }
